@@ -422,8 +422,9 @@ void CameraThread::updateState(const FCam::Frame &frame) {
             viewfinder.gain *= viewfinder.exposure;
             viewfinder.gain /= newExp;
             viewfinder.exposure = newExp;
-            // clamp to minimum gain
+            // clamp to possible gains
             if (viewfinder.gain < 1.0) viewfinder.gain = 1.0;
+            if (viewfinder.gain > 32.0) viewfinder.gain = 32.0;
         } else {
             if (parameters.exposure.mode == CameraParameters::Exposure::AUTO_HDR) {
                 parameters.exposure.value = hdrViewfinder[0].exposure / 1000000.0f;
