@@ -5,6 +5,7 @@
 #include <QCheckBox>
 #include <QLineEdit>
 #include <QRadioButton>
+#include <QPushButton>
 
 /** The tabbed dialog above the viewfinder that provides access to
  * miscellaneous settings and the about page. */
@@ -21,6 +22,7 @@ protected:
     QLineEdit * rawPath, * filePrefix;
     QRadioButton * timestamp, * index;
     QCheckBox * autosaveJPGs;
+    QPushButton * emptyTrashButton, * restoreTrashButton;
     
     // Visualization panel widgets
     QCheckBox * intensityHistogram, *ruleOfThirds;
@@ -39,6 +41,19 @@ public slots:
     // Launches a web browser pointed to the FCam website. Hooked up to
     // the URL button in the about tab.
     void launchBrowserForFCamWebsite();
+    // Delete all trashed photos permanently.
+    void emptyTrash();
+    // Return all trashed photos to the RAW library (possibly renaming
+    // some to avoid name conflicts.)
+    void restoreTrash();
+    // This checks whether there are any .trash files in the library and
+    // sets the trash managing buttons enabled state appropriately.
+    void updateTrashButtons();
+    
+signals:
+    // This signal is emitted for each file that has been restored from the trash.
+    // This will get connected with the thumbnail view's addImageAtPath slot.
+    void restoredFileAtPath(QString);
 };
 
 #endif
