@@ -46,8 +46,8 @@ int main(int argc, char **argv) {
     scrollArea->setGeometry(0, 0, 800, 480);
     Viewfinder *viewfinder = new Viewfinder(cameraThread);
     ThumbnailView *review = new ThumbnailView();
-    
-    scrollArea->addWidget(new ExtendedSettings());
+    ExtendedSettings * extendedSettings = new ExtendedSettings();
+    scrollArea->addWidget(extendedSettings);
     scrollArea->addWidget(viewfinder);
     scrollArea->addWidget(review);
     scrollArea->jumpTo(1);
@@ -81,6 +81,11 @@ int main(int argc, char **argv) {
     QObject::connect(panicHandler, SIGNAL(eventHandled(FCam::Event)),
                      cameraThread, SLOT(failGracefully()));
 
+    QObject::connect(extendedSettings, SIGNAL(restoredFileAtPath(QString)),
+                     review, SLOT(addImageAtPath(QString)));
+    QObject::connect(review, SIGNAL(imageTrashed()),
+                     extendedSettings, SLOT(updateTrashButtons()));
+
     new SplashDialog(&mainWindow);
     
     //review->launchShareDialog();
